<#--  Import necessary modules  -->
<#import "../../application/docbook+xml/common_module_traversal_utils.ftl" as utils>
<#import "../../application/docbook+xml/macros_common_general.ftl" as com>
<#compress>
<#-- Initialize common variables -->
<@com.initializeMainVariables/>
<#-- Root entity -->
<#assign rootEntity = entity.root>
<#-- Define the main macro to be used to retrieve output by the traversal approach -->
<#assign mainMacroName = "printAnnotationsForDocument"/>
<#assign mainMacroArgs = ['sectionDoc', 'entityDocument', 'sectionNode', 'level']/>
<#-- Make global the macroCall as well as each macro used in it -->
<#global mainMacroCall="<@" + mainMacroName + " " + mainMacroArgs?join(" ") + "/>"/>
<#global printAnnotationsForDocument=printAnnotationsForDocument/>
<#-- Print CSV header row -->
<@printCsvHeadersRow />
<#-- Traverse the main entity -->
<@utils.traversal rootEntity 8/>
<#----------------------------------------------->
<#-- Macro and function definitions start here -->
<#----------------------------------------------->
<#macro printAnnotationsForDocument sectionDoc entityDocument sectionNode level>
  <#if level == 0>
    <#local sectionName = "">
    <#if sectionNode?has_content>
      <#if sectionNode.number?has_content>
        <#local sectionName = sectionNode.number + " ">
      </#if>
      <#local sectionName = sectionName + sectionNode.title>
    </#if>
    <#local sectionDocType = sectionDoc.documentType>
    <#if !utils.isEntityDocument(sectionDoc)>
      <#local sectionDocType = sectionDocType + "." + sectionDoc.documentSubType>
    </#if>
    <#-- The web URL pointing to the document -->
    <#local docUrl=utils.getDocumentUrl(sectionDoc) />
    <#-- Get the annotations of the document and print a row for each of them -->
    <#local annotationKeys = sectionDoc.annotations />
    <#if annotationKeys?has_content>
      <#list annotationKeys as key>
        <#local annotation = iuclid.getDocumentForKey(key) />
        <#local annotationStatus = utils.getPicklistFieldAsText(annotation.AdminInfo.AnnotationStatus) />
        <#local annotationAgreement = utils.getPicklistFieldAsText(annotation.EvalInfo.AgreementWithApplicantsSummary) />
        <@utils.csvValue annotation.AdminInfo.Name/>,<@utils.csvValue annotationStatus/>,<@utils.csvValue annotationAgreement/>,<@utils.csvValue annotation.EvalInfo.Remarks/>,<@utils.csvValue entityDocument.name/>,${entityDocument.documentType},${entityDocument.documentKey},<@utils.csvValue sectionName/>,<@utils.csvValue sectionDoc.name/>,${sectionDocType},${sectionDoc.documentKey},<@utils.csvValue docUrl/>
      </#list>
    </#if>
  </#if>
</#macro>

<#macro printCsvHeadersRow>
"Annotation name","Annotation status","Annotation - Agreement with applicant","Annotation - Evaluation remarks","Entity name","Entity type","Entity UUID","TOC Section name","Section document name","Section document type","Section document UUID","URL"
</#macro>
</#compress>
